@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2010-2012 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
  *
  * @package    Ldap
  * @subpackage UnitTests
@@ -46,16 +46,16 @@ class Horde_Ldap_LdifTest extends PHPUnit_Framework_TestCase
             'cn'          => 'test blabla',
             'attr3'       => array('foo', 'bar'),
             'attr1'       => 12345,
-            'attr4'       => 'blabla',
+            'attr4'       => 'blablaöäü',
             'objectclass' => 'oc2',
             'attr2'       => array('1234', 'baz'),
             'verylong'    => 'fhu08rhvt7b478vt5hv78h45nfgt45h78t34hhhhhhhhhv5bg8h6ttttttttt3489t57nhvgh4788trhg8999vnhtgthgui65hgb5789thvngwr789cghm738'),
 
-        'cn=test ,ou=example,dc=cno' => array(
-            'cn'          => 'test ',
+        'cn=test öäü,ou=example,dc=cno' => array(
+            'cn'          => 'test öäü',
             'attr3'       => array('foo', 'bar'),
             'attr1'       => 12345,
-            'attr4'       => 'blabla',
+            'attr4'       => 'blablaöäü',
             'objectclass' => 'oc3',
             'attr2'       => array('1234', 'baz'),
             'attr5'       => 'endspace ',
@@ -91,7 +91,7 @@ class Horde_Ldap_LdifTest extends PHPUnit_Framework_TestCase
         foreach ($this->_testdata as $dn => $attrs) {
             $entry = Horde_Ldap_Entry::createFresh($dn, $attrs);
             $this->assertInstanceOf('Horde_Ldap_Entry', $entry);
-            array_push($this->_testentries, $entry);
+            $this->_testentries[] = $entry;
         }
 
         // Create outfile if not exists and enforce proper access rights.
@@ -190,7 +190,7 @@ class Horde_Ldap_LdifTest extends PHPUnit_Framework_TestCase
         do {
             $entry = $ldif->readEntry();
             $this->assertInstanceOf('Horde_Ldap_Entry', $entry);
-            array_push($entries, $entry);
+            $entries[] = $entry;
         } while (!$ldif->eof());
 
         $this->_compareEntries($this->_testentries, $entries);
@@ -203,7 +203,7 @@ class Horde_Ldap_LdifTest extends PHPUnit_Framework_TestCase
         do {
             $entry = $ldif->readEntry();
             $this->assertInstanceOf('Horde_Ldap_Entry', $entry);
-            array_push($entries, $entry);
+            $entries[] = $entry;
         } while (!$ldif->eof());
 
         $this->_compareEntries($this->_testentries, $entries);
@@ -351,7 +351,7 @@ class Horde_Ldap_LdifTest extends PHPUnit_Framework_TestCase
         do {
             $entry = $ldif->readEntry();
             $this->assertInstanceOf('Horde_Ldap_Entry', $entry);
-            array_push($entries, $entry);
+            $entries[] = $entry;
         } while (!$ldif->eof());
         $ldif->done();
 
